<?php

/**
 * @version    2.0.0
 * @package    Autolinks Plugin
 * @author     Rob Galloway <rob@startearning.com>
 * @copyright  2017 Mitrax Pty Ltd
 * @license    GNU General Public License version 2 or later; see LICENSE.txt
 */

// no direct access
defined('_JEXEC') or die;

jimport('joomla.plugin.plugin');

/**
 * content - Autolinks - Content - Add Links Plugin
 *
 * @package		Joomla.Plugin
 * @subpackage	autolinks.autolinks
 *
 * Version 1.0.2  - Added link state checking to db query
 * Version 1.0.3  - Add check in regexp to ensure links dont get added inside links
 * Version 1.0.4  - Prevent adding of empty anchors when disallowed self referencing link and no description , general tidy up.
 *
 * 
 */

class plgcontentautolinks extends JPlugin {


	 //Constructor.
	function __construct(&$subject, $config = array()) {
		// call parent
		parent::__construct($subject, $config);
	}
        
        

	//Plugin that adds keyword links to content 

	public function onContentPrepare($context, &$article, &$params, $page = 0)
	{
		// Don't run this plugin if content is being indexed
		if ($context == 'com_finder.indexer')
		{
			return true;
		}
 
		//Instantiate document object
		$document = JFactory::getDocument();
		
		//Load jQuery scripts & css from Google CDN
		//More info at https://developers.google.com/speed/libraries/#jquery-ui
		$document->addScript('https://ajax.googleapis.com/ajax/libs/jquery/3.2.1/jquery.min.js');
		$document->addScript('https://ajax.googleapis.com/ajax/libs/jqueryui/1.12.1/jquery-ui.min.js');
		$document->addStyleSheet('https://ajax.googleapis.com/ajax/libs/jqueryui/1.12.1/themes/smoothness/jquery-ui.css');
		
		
		//Initialise tooltip JS & configure behaviour here	
		$script='
			$(document).tooltip({
				content: function(callback){
					callback($(this).prop(\'title\'));
				}
			});		
		';
		
		$document->addScriptDeclaration($script);
 
 
		//Instantiate database object
		$db     = JFactory::getDbo();
		
		// Create a new query object.
		$query = $db->getQuery(true);
		
		//setup the query
		$query
			->select($db->quoteName(array('link_type','text','uri','description','whole_word','follow_link','self_reference','max_replacements')))
			->from($db->quoteName('#__autolinks_link'))
			->where($db->quoteName('state').' = 1');
		
		//execute query
		$db->setQuery($query);
		$rows = $db->loadObjectList();
		
		// perform modifications/substitutions for each keyword
		foreach($rows as $key => $row) {
			
			$href = null;
			$rel  = null;
			$title= null;
			
			//Don't do any more if text not found
			if(!strpos($article->text,$row->text)){continue;}
			
			//Dont do any more if no link or description
			If(!($row->uri||$row->description)){continue;}
			
			//Prepare href for anchor if a URI is present
			if($row->uri){

				//Check for self referencing links
				if($row->self_reference==0){
					$thisPageURI=JURI::getInstance()->toString();
					$href=substr_compare($thisPageURI,$row->uri,-strlen($row->uri))===0?null:' href=\''.$row->uri.'\'';
				
				} else {
					$href=' href=\''.$row->uri.'\'';
				}
				
				//prepare nofollow attribute for link.
				$rel=($row->follow_link==0&&!is_null($href)?' rel=\'nofollow\'':null);
			
			//no href if uri is not present	
			} else { $href = null;}

			//Create title if description has been provided			
			$title=($row->description?' title=\''.$row->description.'\'':null);
			
			//Add anchor to text if a link or title is to be added.
			if($href||$title){
				
				//create anchor
				$replacement = '<a'.$rel.$href.$title.'>'.$row->text.'</a>';
			
				//Turn text to be replaced into a regular expression
				$regText=($row->whole_word==1?'(\b'.preg_quote($row->text,'/').'\b)':'('.preg_quote($row->text,'/').')');
			
				// Perform replacement - TODO :: A bit Q&D Distill this to a single OR if possible & efficient.
				$article->text=preg_replace('/<a[^>]*>.*?<\/a>(*SKIP)(*FAIL)|<[^>]*>(*SKIP)(*FAIL)|'.$regText.'/',$replacement,$article->text,$row->max_replacements);
			}
		}
 
	} 
	
}